@@ -29,13 +29,13 @@
 
 #include "terminal-app.h"
 #include "terminal-accels.h"
+#include "terminal-screen.h"
+#include "terminal-screen-container.h"
 #include "terminal-window.h"
 #include "terminal-util.h"
 #include "profile-editor.h"
 #include "encoding.h"
 #include <gconf/gconf-client.h>
-#include <libgnome/gnome-help.h>
-#include <libgnomeui/gnome-url.h>
 #include <libgnomeui/gnome-client.h>
 #include <string.h>
 #include <stdlib.h>
@@ -224,8 +224,7 @@ terminal_app_create_profile (TerminalApp *app,
 
 static void
 terminal_app_delete_profile (TerminalApp *app,
-                             TerminalProfile *profile,
-                             GtkWindow   *transient_parent)
+                             TerminalProfile *profile)
 {
   GHashTableIter iter;
   GSList *name_list;
@@ -239,12 +238,12 @@ terminal_app_delete_profile (TerminalApp *app,
   name_list = NULL;
   g_hash_table_iter_init (&iter, app->profiles);
   while (g_hash_table_iter_next (&iter, (gpointer*) &name, NULL))
-  {
-    if (strcmp (name, profile_name) == 0)
-      continue;
+    {
+      if (strcmp (name, profile_name) == 0)
+        continue;
 
-    name_list = g_slist_prepend (name_list, g_strdup (name));
-  }
+      name_list = g_slist_prepend (name_list, g_strdup (name));
+    }
 
   gconf_client_set_list (app->conf,
                          CONF_GLOBAL_PREFIX"/profile_list",
@@ -303,7 +302,7 @@ terminal_app_profile_sort_func (GtkTreeModel *model,
   return retval;
 }
 
-static GtkTreeModel *
+static /* ref */ GtkTreeModel *
 terminal_app_get_profile_liststore (TerminalApp *app,
                                     TerminalProfile *selected_profile,
                                     GtkTreeIter *selected_profile_iter,
@@ -520,8 +519,7 @@ profile_list_delete_confirm_response_cb (GtkWidget *dialog,
   g_assert (profile != NULL);
   
   if (response == GTK_RESPONSE_ACCEPT)
-    terminal_app_delete_profile (app, profile,
-                                 gtk_window_get_transient_for (GTK_WINDOW (dialog)));
+    terminal_app_delete_profile (app, profile);
 
   gtk_widget_destroy (dialog);
 }
@@ -1204,22 +1202,25 @@ terminal_app_get_clone_command (TerminalApp *app,
 
       active_screen = terminal_window_get_active (window);
       
-      tabs = terminal_window_list_screens (window);
+      tabs = terminal_window_list_screen_containers (window);
 
       for (lt = tabs; lt != NULL; lt = lt->next)
         {
-          TerminalScreen *screen = lt->data;
+          TerminalScreen *screen;
           const char *profile_id;
           const char **override_command;
           const char *title;
           double zoom;
-          
+
+          screen = terminal_screen_container_get_screen (GTK_WIDGET (lt->data));
           profile_id = terminal_profile_get_property_string (terminal_screen_get_profile (screen),
                                                              TERMINAL_PROFILE_NAME);
           
           if (lt == tabs)
             {
-               g_ptr_array_add (args, g_strdup_printf ("--window-with-profile-internal-id=%s",
+              GdkWindowState state;
+                
+              g_ptr_array_add (args, g_strdup_printf ("--window-with-profile-internal-id=%s",
                                                      profile_id));
               if (terminal_window_get_menubar_visible (window))
                  g_ptr_array_add (args, g_strdup ("--show-menubar"));
@@ -1228,6 +1229,12 @@ terminal_app_get_clone_command (TerminalApp *app,
 
                g_ptr_array_add (args, g_strdup_printf ("--role=%s",
                                                        gtk_window_get_role (GTK_WINDOW (window))));
+
+               state = gdk_window_get_state (GTK_WIDGET (window)->window);
+               if (state & GDK_WINDOW_STATE_MAXIMIZED)
+                 g_ptr_array_add (args, g_strdup ("--maximize"));
+               if (state & GDK_WINDOW_STATE_FULLSCREEN)
+                 g_ptr_array_add (args, g_strdup ("--full-screen"));
             }
           else
             {
@@ -1557,7 +1564,6 @@ terminal_app_class_init (TerminalAppClass *klass)
                          PANGO_TYPE_FONT_DESCRIPTION,
                          G_PARAM_READABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
 
-  /* FIMXEchpe make rw prop */
   g_object_class_install_property
     (object_class,
      PROP_DEFAULT_PROFILE,
